from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MetricType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNKNOWN: _ClassVar[MetricType]
    INTEGER: _ClassVar[MetricType]
    DECIMAL: _ClassVar[MetricType]
    TEXT: _ClassVar[MetricType]
    DATE: _ClassVar[MetricType]
    TRUTH: _ClassVar[MetricType]
    URL: _ClassVar[MetricType]

class OperationEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    GET: _ClassVar[OperationEnum]
    CREATE: _ClassVar[OperationEnum]
    READ: _ClassVar[OperationEnum]
    UPDATE: _ClassVar[OperationEnum]
    DELETE: _ClassVar[OperationEnum]
    MATCHING: _ClassVar[OperationEnum]
    BULK_CREATE: _ClassVar[OperationEnum]
    AVAILABLE_METRICS: _ClassVar[OperationEnum]
UNKNOWN: MetricType
INTEGER: MetricType
DECIMAL: MetricType
TEXT: MetricType
DATE: MetricType
TRUTH: MetricType
URL: MetricType
GET: OperationEnum
CREATE: OperationEnum
READ: OperationEnum
UPDATE: OperationEnum
DELETE: OperationEnum
MATCHING: OperationEnum
BULK_CREATE: OperationEnum
AVAILABLE_METRICS: OperationEnum

class MetricMatchingObject(_message.Message):
    __slots__ = ["metric_uuid", "match_to_metric_uuid"]
    METRIC_UUID_FIELD_NUMBER: _ClassVar[int]
    MATCH_TO_METRIC_UUID_FIELD_NUMBER: _ClassVar[int]
    metric_uuid: str
    match_to_metric_uuid: str
    def __init__(self, metric_uuid: _Optional[str] = ..., match_to_metric_uuid: _Optional[str] = ...) -> None: ...

class MetricsMatchingRequest(_message.Message):
    __slots__ = ["metrics", "connect_portal_uuid"]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    CONNECT_PORTAL_UUID_FIELD_NUMBER: _ClassVar[int]
    metrics: _containers.RepeatedCompositeFieldContainer[MetricMatchingObject]
    connect_portal_uuid: str
    def __init__(self, metrics: _Optional[_Iterable[_Union[MetricMatchingObject, _Mapping]]] = ..., connect_portal_uuid: _Optional[str] = ...) -> None: ...

class MetricReadRequest(_message.Message):
    __slots__ = ["company_uuid"]
    COMPANY_UUID_FIELD_NUMBER: _ClassVar[int]
    company_uuid: str
    def __init__(self, company_uuid: _Optional[str] = ...) -> None: ...

class MetricGetRequest(_message.Message):
    __slots__ = ["metric_uuid"]
    METRIC_UUID_FIELD_NUMBER: _ClassVar[int]
    metric_uuid: str
    def __init__(self, metric_uuid: _Optional[str] = ...) -> None: ...

class MetricCreateRequest(_message.Message):
    __slots__ = ["connect_portal_uuid", "company_uuid", "key", "name", "custom", "connect_portal_method", "type", "configuration", "connected_metrics"]
    CONNECT_PORTAL_UUID_FIELD_NUMBER: _ClassVar[int]
    COMPANY_UUID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    CONNECT_PORTAL_METHOD_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_METRICS_FIELD_NUMBER: _ClassVar[int]
    connect_portal_uuid: str
    company_uuid: str
    key: str
    name: str
    custom: bool
    connect_portal_method: str
    type: MetricType
    configuration: _any_pb2.Any
    connected_metrics: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, connect_portal_uuid: _Optional[str] = ..., company_uuid: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., custom: bool = ..., connect_portal_method: _Optional[str] = ..., type: _Optional[_Union[MetricType, str]] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., connected_metrics: _Optional[_Iterable[str]] = ...) -> None: ...

class MetricBulkCreateRequest(_message.Message):
    __slots__ = ["metrics", "connect_portal_uuid"]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    CONNECT_PORTAL_UUID_FIELD_NUMBER: _ClassVar[int]
    metrics: _containers.RepeatedCompositeFieldContainer[MetricCreateRequest]
    connect_portal_uuid: str
    def __init__(self, metrics: _Optional[_Iterable[_Union[MetricCreateRequest, _Mapping]]] = ..., connect_portal_uuid: _Optional[str] = ...) -> None: ...

class MetricUpdateRequest(_message.Message):
    __slots__ = ["metric_uuid", "name", "type", "configuration", "connected_metrics"]
    METRIC_UUID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_METRICS_FIELD_NUMBER: _ClassVar[int]
    metric_uuid: str
    name: str
    type: MetricType
    configuration: _any_pb2.Any
    connected_metrics: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, metric_uuid: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[_Union[MetricType, str]] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., connected_metrics: _Optional[_Iterable[str]] = ...) -> None: ...

class MetricDeleteRequest(_message.Message):
    __slots__ = ["metric_uuid"]
    METRIC_UUID_FIELD_NUMBER: _ClassVar[int]
    metric_uuid: str
    def __init__(self, metric_uuid: _Optional[str] = ...) -> None: ...

class MetricResponse(_message.Message):
    __slots__ = ["operation", "success", "uuid", "key", "name", "custom", "type", "connect_portal_uuid", "company_uuid", "connected_metrics", "connect_portal_method", "configuration", "created_at", "updated_at"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CONNECT_PORTAL_UUID_FIELD_NUMBER: _ClassVar[int]
    COMPANY_UUID_FIELD_NUMBER: _ClassVar[int]
    CONNECTED_METRICS_FIELD_NUMBER: _ClassVar[int]
    CONNECT_PORTAL_METHOD_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    uuid: str
    key: str
    name: str
    custom: bool
    type: MetricType
    connect_portal_uuid: str
    company_uuid: str
    connected_metrics: _containers.RepeatedScalarFieldContainer[str]
    connect_portal_method: str
    configuration: _any_pb2.Any
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., uuid: _Optional[str] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., custom: bool = ..., type: _Optional[_Union[MetricType, str]] = ..., connect_portal_uuid: _Optional[str] = ..., company_uuid: _Optional[str] = ..., connected_metrics: _Optional[_Iterable[str]] = ..., connect_portal_method: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class MetricsResponse(_message.Message):
    __slots__ = ["operation", "success", "metrics"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    METRICS_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    metrics: _containers.RepeatedCompositeFieldContainer[MetricResponse]
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., metrics: _Optional[_Iterable[_Union[MetricResponse, _Mapping]]] = ...) -> None: ...

class AvailableMetricsRequest(_message.Message):
    __slots__ = ["connect_portal_uuid"]
    CONNECT_PORTAL_UUID_FIELD_NUMBER: _ClassVar[int]
    connect_portal_uuid: str
    def __init__(self, connect_portal_uuid: _Optional[str] = ...) -> None: ...

class AvailableValues(_message.Message):
    __slots__ = ["metric_key", "values"]
    METRIC_KEY_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    metric_key: str
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, metric_key: _Optional[str] = ..., values: _Optional[_Iterable[str]] = ...) -> None: ...

class AvailableValuesResponse(_message.Message):
    __slots__ = ["available_values"]
    AVAILABLE_VALUES_FIELD_NUMBER: _ClassVar[int]
    available_values: _containers.RepeatedCompositeFieldContainer[AvailableValues]
    def __init__(self, available_values: _Optional[_Iterable[_Union[AvailableValues, _Mapping]]] = ...) -> None: ...

class AvailableValuesRequest(_message.Message):
    __slots__ = ["company_uuid", "metric_keys"]
    COMPANY_UUID_FIELD_NUMBER: _ClassVar[int]
    METRIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    company_uuid: str
    metric_keys: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, company_uuid: _Optional[str] = ..., metric_keys: _Optional[_Iterable[str]] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OperationEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    GET: _ClassVar[OperationEnum]
    CREATE: _ClassVar[OperationEnum]
    READ: _ClassVar[OperationEnum]
    UPDATE: _ClassVar[OperationEnum]
    DELETE: _ClassVar[OperationEnum]
GET: OperationEnum
CREATE: OperationEnum
READ: OperationEnum
UPDATE: OperationEnum
DELETE: OperationEnum

class CompanyGetRequest(_message.Message):
    __slots__ = ["company_key"]
    COMPANY_KEY_FIELD_NUMBER: _ClassVar[int]
    company_key: str
    def __init__(self, company_key: _Optional[str] = ...) -> None: ...

class CompanyCreateRequest(_message.Message):
    __slots__ = ["platform_uuid", "name", "configuration"]
    PLATFORM_UUID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    platform_uuid: _containers.RepeatedScalarFieldContainer[str]
    name: str
    configuration: _any_pb2.Any
    def __init__(self, platform_uuid: _Optional[_Iterable[str]] = ..., name: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class CompanyUpdateRequest(_message.Message):
    __slots__ = ["uuid", "platform_uuid", "name", "configuration"]
    UUID_FIELD_NUMBER: _ClassVar[int]
    PLATFORM_UUID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    uuid: str
    platform_uuid: _containers.RepeatedScalarFieldContainer[str]
    name: str
    configuration: _any_pb2.Any
    def __init__(self, uuid: _Optional[str] = ..., platform_uuid: _Optional[_Iterable[str]] = ..., name: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class CompanyResponse(_message.Message):
    __slots__ = ["operation", "success", "uuid", "platforms", "key", "name", "configuration", "created_at", "updated_at"]
    class platform_ids(_message.Message):
        __slots__ = ["platform_uuid"]
        PLATFORM_UUID_FIELD_NUMBER: _ClassVar[int]
        platform_uuid: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, platform_uuid: _Optional[_Iterable[str]] = ...) -> None: ...
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    PLATFORMS_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    operation: OperationEnum
    success: bool
    uuid: str
    platforms: CompanyResponse.platform_ids
    key: str
    name: str
    configuration: _any_pb2.Any
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, operation: _Optional[_Union[OperationEnum, str]] = ..., success: bool = ..., uuid: _Optional[str] = ..., platforms: _Optional[_Union[CompanyResponse.platform_ids, _Mapping]] = ..., key: _Optional[str] = ..., name: _Optional[str] = ..., configuration: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OverviewRequest(_message.Message):
    __slots__ = ["chart_uuids", "overview_uuid", "params"]
    CHART_UUIDS_FIELD_NUMBER: _ClassVar[int]
    OVERVIEW_UUID_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    chart_uuids: _containers.RepeatedScalarFieldContainer[str]
    overview_uuid: str
    params: DispatcherParams
    def __init__(self, chart_uuids: _Optional[_Iterable[str]] = ..., overview_uuid: _Optional[str] = ..., params: _Optional[_Union[DispatcherParams, _Mapping]] = ...) -> None: ...

class DispatcherRequest(_message.Message):
    __slots__ = ["chart_uuid", "params"]
    CHART_UUID_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    chart_uuid: str
    params: DispatcherParams
    def __init__(self, chart_uuid: _Optional[str] = ..., params: _Optional[_Union[DispatcherParams, _Mapping]] = ...) -> None: ...

class DispatcherFilter(_message.Message):
    __slots__ = ["metric", "opterator", "values"]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    OPTERATOR_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    metric: str
    opterator: str
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, metric: _Optional[str] = ..., opterator: _Optional[str] = ..., values: _Optional[_Iterable[str]] = ...) -> None: ...

class DispatcherParams(_message.Message):
    __slots__ = ["start_date", "end_date", "filters", "requested_fields", "session_uuid"]
    START_DATE_FIELD_NUMBER: _ClassVar[int]
    END_DATE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    REQUESTED_FIELDS_FIELD_NUMBER: _ClassVar[int]
    SESSION_UUID_FIELD_NUMBER: _ClassVar[int]
    start_date: str
    end_date: str
    filters: _containers.RepeatedCompositeFieldContainer[DispatcherFilter]
    requested_fields: _containers.RepeatedScalarFieldContainer[str]
    session_uuid: str
    def __init__(self, start_date: _Optional[str] = ..., end_date: _Optional[str] = ..., filters: _Optional[_Iterable[_Union[DispatcherFilter, _Mapping]]] = ..., requested_fields: _Optional[_Iterable[str]] = ..., session_uuid: _Optional[str] = ...) -> None: ...

class DispatcherResponse(_message.Message):
    __slots__ = ["success", "cached", "payload"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    CACHED_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    success: bool
    cached: bool
    payload: _any_pb2.Any
    def __init__(self, success: bool = ..., cached: bool = ..., payload: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cmetric.proto\x12\x10\x63onnector.metric\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"I\n\x14MetricMatchingObject\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\x12\x1c\n\x14match_to_metric_uuid\x18\x02 \x01(\t\"n\n\x16MetricsMatchingRequest\x12\x37\n\x07metrics\x18\x01 \x03(\x0b\x32&.connector.metric.MetricMatchingObject\x12\x1b\n\x13\x63onnect_portal_uuid\x18\x02 \x01(\t\")\n\x11MetricReadRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\"\'\n\x10MetricGetRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\"\xbc\x02\n\x13MetricCreateRequest\x12\x1b\n\x13\x63onnect_portal_uuid\x18\x01 \x01(\t\x12\x14\n\x0c\x63ompany_uuid\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06\x63ustom\x18\x05 \x01(\x08\x12\"\n\x15\x63onnect_portal_method\x18\x06 \x01(\tH\x00\x88\x01\x01\x12*\n\x04type\x18\x07 \x01(\x0e\x32\x1c.connector.metric.MetricType\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x12\x19\n\x11\x63onnected_metrics\x18\t \x03(\tB\x18\n\x16_connect_portal_methodB\x10\n\x0e_configuration\"n\n\x17MetricBulkCreateRequest\x12\x36\n\x07metrics\x18\x01 \x03(\x0b\x32%.connector.metric.MetricCreateRequest\x12\x1b\n\x13\x63onnect_portal_uuid\x18\x02 \x01(\t\"\xac\x01\n\x13MetricUpdateRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x04type\x18\x03 \x01(\x0e\x32\x1c.connector.metric.MetricType\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x63onnected_metrics\x18\x05 \x03(\t\"*\n\x13MetricDeleteRequest\x12\x13\n\x0bmetric_uuid\x18\x01 \x01(\t\"\xb0\x05\n\x0eMetricResponse\x12\x37\n\toperation\x18\x01 \x01(\x0e\x32\x1f.connector.metric.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x03key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12/\n\x04type\x18\x07 \x01(\x0e\x32\x1c.connector.metric.MetricTypeH\x06\x88\x01\x01\x12 \n\x13\x63onnect_portal_uuid\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x19\n\x0c\x63ompany_uuid\x18\t \x01(\tH\x08\x88\x01\x01\x12\x19\n\x11\x63onnected_metrics\x18\n \x03(\t\x12\"\n\x15\x63onnect_portal_method\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x30\n\rconfiguration\x18\x0c \x01(\x0b\x32\x14.google.protobuf.AnyH\n\x88\x01\x01\x12\x33\n\ncreated_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0b\x88\x01\x01\x12\x33\n\nupdated_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0c\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x06\n\x04_keyB\x07\n\x05_nameB\t\n\x07_customB\x07\n\x05_typeB\x16\n\x14_connect_portal_uuidB\x0f\n\r_company_uuidB\x18\n\x16_connect_portal_methodB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x89\x01\n\x0fMetricsResponse\x12\x32\n\toperation\x18\x01 \x01(\x0e\x32\x1f.connector.metric.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x31\n\x07metrics\x18\x03 \x03(\x0b\x32 .connector.metric.MetricResponse\"6\n\x17\x41vailableMetricsRequest\x12\x1b\n\x13\x63onnect_portal_uuid\x18\x01 \x01(\t\"5\n\x0f\x41vailableValues\x12\x12\n\nmetric_key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"V\n\x17\x41vailableValuesResponse\x12;\n\x10\x61vailable_values\x18\x01 \x03(\x0b\x32!.connector.metric.AvailableValues\"C\n\x16\x41vailableValuesRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\x12\x13\n\x0bmetric_keys\x18\x02 \x03(\t*[\n\nMetricType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\x0b\n\x07\x44\x45\x43IMAL\x10\x02\x12\x08\n\x04TEXT\x10\x03\x12\x08\n\x04\x44\x41TE\x10\x04\x12\t\n\x05TRUTH\x10\x05\x12\x07\n\x03URL\x10\x06*|\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x0c\n\x08MATCHING\x10\x05\x12\x0f\n\x0b\x42ULK_CREATE\x10\x06\x12\x15\n\x11\x41VAILABLE_METRICS\x10\x07\x32\xab\x06\n\rMetricService\x12N\n\x04Read\x12#.connector.metric.MetricReadRequest\x1a!.connector.metric.MetricsResponse\x12K\n\x03Get\x12\".connector.metric.MetricGetRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06\x43reate\x12%.connector.metric.MetricCreateRequest\x1a .connector.metric.MetricResponse\x12Z\n\nBulkCreate\x12).connector.metric.MetricBulkCreateRequest\x1a!.connector.metric.MetricsResponse\x12Q\n\x06Update\x12%.connector.metric.MetricUpdateRequest\x1a .connector.metric.MetricResponse\x12Q\n\x06\x44\x65lete\x12%.connector.metric.MetricDeleteRequest\x1a .connector.metric.MetricResponse\x12`\n\x10\x41vailableMetrics\x12).connector.metric.AvailableMetricsRequest\x1a!.connector.metric.MetricsResponse\x12\x66\n\x0f\x41vailableValues\x12(.connector.metric.AvailableValuesRequest\x1a).connector.metric.AvailableValuesResponse\x12^\n\x0fMetricsMatching\x12(.connector.metric.MetricsMatchingRequest\x1a!.connector.metric.MetricsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_METRICTYPE']._serialized_start=2114
  _globals['_METRICTYPE']._serialized_end=2205
  _globals['_OPERATIONENUM']._serialized_start=2207
  _globals['_OPERATIONENUM']._serialized_end=2331
  _globals['_METRICMATCHINGOBJECT']._serialized_start=94
  _globals['_METRICMATCHINGOBJECT']._serialized_end=167
  _globals['_METRICSMATCHINGREQUEST']._serialized_start=169
  _globals['_METRICSMATCHINGREQUEST']._serialized_end=279
  _globals['_METRICREADREQUEST']._serialized_start=281
  _globals['_METRICREADREQUEST']._serialized_end=322
  _globals['_METRICGETREQUEST']._serialized_start=324
  _globals['_METRICGETREQUEST']._serialized_end=363
  _globals['_METRICCREATEREQUEST']._serialized_start=366
  _globals['_METRICCREATEREQUEST']._serialized_end=682
  _globals['_METRICBULKCREATEREQUEST']._serialized_start=684
  _globals['_METRICBULKCREATEREQUEST']._serialized_end=794
  _globals['_METRICUPDATEREQUEST']._serialized_start=797
  _globals['_METRICUPDATEREQUEST']._serialized_end=969
  _globals['_METRICDELETEREQUEST']._serialized_start=971
  _globals['_METRICDELETEREQUEST']._serialized_end=1013
  _globals['_METRICRESPONSE']._serialized_start=1016
  _globals['_METRICRESPONSE']._serialized_end=1704
  _globals['_METRICSRESPONSE']._serialized_start=1707
  _globals['_METRICSRESPONSE']._serialized_end=1844
  _globals['_AVAILABLEMETRICSREQUEST']._serialized_start=1846
  _globals['_AVAILABLEMETRICSREQUEST']._serialized_end=1900
  _globals['_AVAILABLEVALUES']._serialized_start=1902
  _globals['_AVAILABLEVALUES']._serialized_end=1955
  _globals['_AVAILABLEVALUESRESPONSE']._serialized_start=1957
  _globals['_AVAILABLEVALUESRESPONSE']._serialized_end=2043
  _globals['_AVAILABLEVALUESREQUEST']._serialized_start=2045
  _globals['_AVAILABLEVALUESREQUEST']._serialized_end=2112
  _globals['_METRICSERVICE']._serialized_start=2334
  _globals['_METRICSERVICE']._serialized_end=3145
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x12\x13\x63onnector.connector\x1a\x19google/protobuf/any.proto\"\x84\x01\n\x0fOverviewRequest\x12\x13\n\x0b\x63hart_uuids\x18\x01 \x03(\t\x12\x15\n\roverview_uuid\x18\x02 \x01(\t\x12:\n\x06params\x18\x03 \x01(\x0b\x32%.connector.connector.DispatcherParamsH\x00\x88\x01\x01\x42\t\n\x07_params\"n\n\x11\x44ispatcherRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32%.connector.connector.DispatcherParamsH\x00\x88\x01\x01\x42\t\n\x07_params\"E\n\x10\x44ispatcherFilter\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12\x11\n\topterator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xb6\x01\n\x10\x44ispatcherParams\x12\x12\n\nstart_date\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x02 \x01(\t\x12\x36\n\x07\x66ilters\x18\x03 \x03(\x0b\x32%.connector.connector.DispatcherFilter\x12\x18\n\x10requested_fields\x18\x04 \x03(\t\x12\x19\n\x0csession_uuid\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_session_uuid\"\\\n\x12\x44ispatcherResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06\x63\x61\x63hed\x18\x02 \x01(\x08\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any2\xba\x02\n\x10\x43onnectorService\x12_\n\nDispatcher\x12&.connector.connector.DispatcherRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x12\x64\n\x13OverviewCacheUpdate\x12$.connector.connector.OverviewRequest\x1a\'.connector.connector.DispatcherResponse\x12_\n\x0cOverviewData\x12$.connector.connector.OverviewRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OVERVIEWREQUEST']._serialized_start=68
  _globals['_OVERVIEWREQUEST']._serialized_end=200
  _globals['_DISPATCHERREQUEST']._serialized_start=202
  _globals['_DISPATCHERREQUEST']._serialized_end=312
  _globals['_DISPATCHERFILTER']._serialized_start=314
  _globals['_DISPATCHERFILTER']._serialized_end=383
  _globals['_DISPATCHERPARAMS']._serialized_start=386
  _globals['_DISPATCHERPARAMS']._serialized_end=568
  _globals['_DISPATCHERRESPONSE']._serialized_start=570
  _globals['_DISPATCHERRESPONSE']._serialized_end=662
  _globals['_CONNECTORSERVICE']._serialized_start=665
  _globals['_CONNECTORSERVICE']._serialized_end=979
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: company.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcompany.proto\x12\x11\x63onnector.company\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"(\n\x11\x43ompanyGetRequest\x12\x13\n\x0b\x63ompany_key\x18\x01 \x01(\t\"\x7f\n\x14\x43ompanyCreateRequest\x12\x15\n\rplatform_uuid\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x88\x01\x01\x42\x10\n\x0e_configuration\"\x9b\x01\n\x14\x43ompanyUpdateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\rplatform_uuid\x18\x02 \x03(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x30\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_configuration\"\x97\x04\n\x0f\x43ompanyResponse\x12\x38\n\toperation\x18\x01 \x01(\x0e\x32 .connector.company.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12G\n\tplatforms\x18\x04 \x01(\x0b\x32/.connector.company.CompanyResponse.platform_idsH\x03\x88\x01\x01\x12\x10\n\x03key\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x11\n\x04name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x30\n\rconfiguration\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyH\x06\x88\x01\x01\x12\x33\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x07\x88\x01\x01\x12\x33\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x1a%\n\x0cplatform_ids\x12\x15\n\rplatform_uuid\x18\x01 \x03(\tB\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x0c\n\n_platformsB\x06\n\x04_keyB\x07\n\x05_nameB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32\x8f\x02\n\x0e\x43ompanyService\x12O\n\x03Get\x12$.connector.company.CompanyGetRequest\x1a\".connector.company.CompanyResponse\x12U\n\x06\x43reate\x12\'.connector.company.CompanyCreateRequest\x1a\".connector.company.CompanyResponse\x12U\n\x06Update\x12\'.connector.company.CompanyUpdateRequest\x1a\".connector.company.CompanyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'company_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OPERATIONENUM']._serialized_start=963
  _globals['_OPERATIONENUM']._serialized_end=1033
  _globals['_COMPANYGETREQUEST']._serialized_start=96
  _globals['_COMPANYGETREQUEST']._serialized_end=136
  _globals['_COMPANYCREATEREQUEST']._serialized_start=138
  _globals['_COMPANYCREATEREQUEST']._serialized_end=265
  _globals['_COMPANYUPDATEREQUEST']._serialized_start=268
  _globals['_COMPANYUPDATEREQUEST']._serialized_end=423
  _globals['_COMPANYRESPONSE']._serialized_start=426
  _globals['_COMPANYRESPONSE']._serialized_end=961
  _globals['_COMPANYRESPONSE_PLATFORM_IDS']._serialized_start=810
  _globals['_COMPANYRESPONSE_PLATFORM_IDS']._serialized_end=847
  _globals['_COMPANYSERVICE']._serialized_start=1036
  _globals['_COMPANYSERVICE']._serialized_end=1307
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import company_pb2 as company__pb2


class CompanyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/connector.company.CompanyService/Get',
                request_serializer=company__pb2.CompanyGetRequest.SerializeToString,
                response_deserializer=company__pb2.CompanyResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/connector.company.CompanyService/Create',
                request_serializer=company__pb2.CompanyCreateRequest.SerializeToString,
                response_deserializer=company__pb2.CompanyResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/connector.company.CompanyService/Update',
                request_serializer=company__pb2.CompanyUpdateRequest.SerializeToString,
                response_deserializer=company__pb2.CompanyResponse.FromString,
                )


class CompanyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CompanyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=company__pb2.CompanyGetRequest.FromString,
                    response_serializer=company__pb2.CompanyResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=company__pb2.CompanyCreateRequest.FromString,
                    response_serializer=company__pb2.CompanyResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=company__pb2.CompanyUpdateRequest.FromString,
                    response_serializer=company__pb2.CompanyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'connector.company.CompanyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CompanyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.company.CompanyService/Get',
            company__pb2.CompanyGetRequest.SerializeToString,
            company__pb2.CompanyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.company.CompanyService/Create',
            company__pb2.CompanyCreateRequest.SerializeToString,
            company__pb2.CompanyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.company.CompanyService/Update',
            company__pb2.CompanyUpdateRequest.SerializeToString,
            company__pb2.CompanyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import connect_portal_pb2 as connect__portal__pb2


class ConnectPortalServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Get',
                request_serializer=connect__portal__pb2.PortalGetRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Create',
                request_serializer=connect__portal__pb2.PortalCreateRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.Read = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Read',
                request_serializer=connect__portal__pb2.PortalReadRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalsResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Update',
                request_serializer=connect__portal__pb2.PortalUpdateRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Delete',
                request_serializer=connect__portal__pb2.PortalDeleteRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.CheckAuthentication = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/CheckAuthentication',
                request_serializer=connect__portal__pb2.PortalMetricRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )


class ConnectPortalServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Read(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAuthentication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectPortalServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=connect__portal__pb2.PortalGetRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=connect__portal__pb2.PortalCreateRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'Read': grpc.unary_unary_rpc_method_handler(
                    servicer.Read,
                    request_deserializer=connect__portal__pb2.PortalReadRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalsResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=connect__portal__pb2.PortalUpdateRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=connect__portal__pb2.PortalDeleteRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'CheckAuthentication': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAuthentication,
                    request_deserializer=connect__portal__pb2.PortalMetricRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'connector.connect_portal.ConnectPortalService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectPortalService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Get',
            connect__portal__pb2.PortalGetRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Create',
            connect__portal__pb2.PortalCreateRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Read',
            connect__portal__pb2.PortalReadRequest.SerializeToString,
            connect__portal__pb2.PortalsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Update',
            connect__portal__pb2.PortalUpdateRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Delete',
            connect__portal__pb2.PortalDeleteRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAuthentication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/CheckAuthentication',
            connect__portal__pb2.PortalMetricRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connect_portal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63onnect_portal.proto\x12\x18\x63onnector.connect_portal\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\'\n\x10PortalGetRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\")\n\x11PortalReadRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\"*\n\x13PortalDeleteRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\"*\n\x13PortalMetricRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\"\xab\x01\n\x13PortalCreateRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\x04type\x18\x03 \x01(\x0e\x32\".connector.connect_portal.TypeEnum\x12\x11\n\tclassName\x18\x04 \x01(\t\x12+\n\rconfiguration\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\"\x8a\x01\n\x13PortalUpdateRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x30\n\rconfiguration\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_configuration\"\x85\x04\n\x0ePortalResponse\x12?\n\toperation\x18\x01 \x01(\x0e\x32\'.connector.connect_portal.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\".connector.connect_portal.TypeEnumH\x04\x88\x01\x01\x12\x10\n\x03key\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tclassName\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x07\x88\x01\x01\x12\x33\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x33\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\t\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x07\n\x05_nameB\x07\n\x05_typeB\x06\n\x04_keyB\x0c\n\n_classNameB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x99\x01\n\x0fPortalsResponse\x12:\n\toperation\x18\x01 \x01(\x0e\x32\'.connector.connect_portal.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x39\n\x07portals\x18\x03 \x03(\x0b\x32(.connector.connect_portal.PortalResponse*1\n\x08TypeEnum\x12\x07\n\x03\x41TS\x10\x00\x12\x0b\n\x07\x43HANNEL\x10\x01\x12\x0f\n\x0bINTEGRATION\x10\x02*b\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04SYNC\x10\x05\x12\x10\n\x0c\x41UTHENTICATE\x10\x06\x32\xec\x04\n\x14\x43onnectPortalService\x12[\n\x03Get\x12*.connector.connect_portal.PortalGetRequest\x1a(.connector.connect_portal.PortalResponse\x12\x61\n\x06\x43reate\x12-.connector.connect_portal.PortalCreateRequest\x1a(.connector.connect_portal.PortalResponse\x12^\n\x04Read\x12+.connector.connect_portal.PortalReadRequest\x1a).connector.connect_portal.PortalsResponse\x12\x61\n\x06Update\x12-.connector.connect_portal.PortalUpdateRequest\x1a(.connector.connect_portal.PortalResponse\x12\x61\n\x06\x44\x65lete\x12-.connector.connect_portal.PortalDeleteRequest\x1a(.connector.connect_portal.PortalResponse\x12n\n\x13\x43heckAuthentication\x12-.connector.connect_portal.PortalMetricRequest\x1a(.connector.connect_portal.PortalResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connect_portal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TYPEENUM']._serialized_start=1273
  _globals['_TYPEENUM']._serialized_end=1322
  _globals['_OPERATIONENUM']._serialized_start=1324
  _globals['_OPERATIONENUM']._serialized_end=1422
  _globals['_PORTALGETREQUEST']._serialized_start=110
  _globals['_PORTALGETREQUEST']._serialized_end=149
  _globals['_PORTALREADREQUEST']._serialized_start=151
  _globals['_PORTALREADREQUEST']._serialized_end=192
  _globals['_PORTALDELETEREQUEST']._serialized_start=194
  _globals['_PORTALDELETEREQUEST']._serialized_end=236
  _globals['_PORTALMETRICREQUEST']._serialized_start=238
  _globals['_PORTALMETRICREQUEST']._serialized_end=280
  _globals['_PORTALCREATEREQUEST']._serialized_start=283
  _globals['_PORTALCREATEREQUEST']._serialized_end=454
  _globals['_PORTALUPDATEREQUEST']._serialized_start=457
  _globals['_PORTALUPDATEREQUEST']._serialized_end=595
  _globals['_PORTALRESPONSE']._serialized_start=598
  _globals['_PORTALRESPONSE']._serialized_end=1115
  _globals['_PORTALSRESPONSE']._serialized_start=1118
  _globals['_PORTALSRESPONSE']._serialized_end=1271
  _globals['_CONNECTPORTALSERVICE']._serialized_start=1425
  _globals['_CONNECTPORTALSERVICE']._serialized_end=2045
# @@protoc_insertion_point(module_scope)
